/**
 *
 */

import cn.hutool.core.date.DateField;
import cn.hutool.core.date.DateTime;
import cn.hutool.core.date.DateUtil;
import lombok.extern.slf4j.Slf4j;
import net.wanji.opt.SignalOptimizeApplication;
import net.wanji.opt.dao.mapper.judgeanalysis.AnalysisProblemCrossDayMapper;
import net.wanji.opt.servicev2.evaluation.EventInfoService;
import org.junit.FixMethodOrder;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.junit.runners.MethodSorters;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.context.junit4.SpringRunner;

import javax.annotation.Resource;
import java.text.ParseException;
import java.util.Date;

/**
 * @author fengyi
 * @date
 */
@RunWith(SpringRunner.class)
@SpringBootTest(classes = SignalOptimizeApplication.class, webEnvironment = SpringBootTest.WebEnvironment.RANDOM_PORT)
@FixMethodOrder(MethodSorters.NAME_ASCENDING)
@Slf4j
public class AnalysisProblemDayTaskTest {

    @Autowired
    private AnalysisProblemCrossDayMapper analysisProblemCrossDayMapper;
    @Resource
    EventInfoService eventInfoService;

    @Test
    public void testProducerTrack() {

        long st = System.currentTimeMillis();
        DateTime startTDateTime = DateUtil.beginOfDay(new Date());
        DateTime endTDateTime = DateUtil.date(); //DateUtil.offsetHour(startTDateTime,1);

        while (startTDateTime.isBefore(endTDateTime)) {

            String sdt = startTDateTime.toString("yyyy-MM-dd HH:00:00");

            startTDateTime = DateUtil.offsetHour(startTDateTime, 1);
            startTDateTime = DateUtil.offsetSecond(startTDateTime, -1);

            String edt = startTDateTime.toString("yyyy-MM-dd HH:mm:ss");

            analysisProblemCrossDayMapper.insertGreenCrossHourData(sdt, edt);

            startTDateTime = DateUtil.offsetSecond(startTDateTime, 1);
            log.info("小时粒度数据入库，小时开始时间：{},小时截止时间：{}，截止时间：{}", sdt, edt, endTDateTime.toString("yyyy-MM-dd HH:mm:ss"));

        }

        long et = System.currentTimeMillis();
        System.out.println((et - st) + "ms");

    }

    @Test
    public void insertCrossSlowRunEventData() throws ParseException {
        try {
            for (int i = 28; i > 0; i--) {
                DateTime endTDateTime = DateUtil.date();

                //开始时间
                DateTime startTDateTime = DateUtil.offsetDay(endTDateTime, -i);
                startTDateTime = DateUtil.beginOfDay(startTDateTime);
                String sdt = startTDateTime.toString("yyyy-MM-dd HH:00:00");

                //窗口截止时间
                endTDateTime = DateUtil.parseDateTime(sdt).offset(DateField.HOUR, 24).offset(DateField.SECOND, -1);
                String edt = endTDateTime.toString("yyyy-MM-dd HH:mm:ss");

                eventInfoService.insertCrossSlowRunEventData(sdt, edt);
            }
        } catch (Exception e) {
            log.error("", e);
        }
    }

    @Test
    public void insertCrossSlowRunDayData() throws ParseException {
        try {
            //路口缓行事件数据单独计算
            DateTime yesterday = DateUtil.yesterday();
            String dt = yesterday.toString("yyyyMMdd");
            for (int i = 20250401; i < 20250428; i++) {
                long st = System.currentTimeMillis();
                analysisProblemCrossDayMapper.insertAnalysisCrossSlowRunDay(i);
                long et = System.currentTimeMillis();
                log.info("路口缓行按天统计：耗时{}ms,dt={}", et-st,i);
            }
        } catch (Exception e) {
            log.error("", e);
        }
    }

}
